import asyncio
import logging
from pathlib import Path
import random
import re
from datetime import datetime

from clockblocker_bot.config import config
from clockblocker_bot.utils.constants import CLOCKBLOCKER_ID, S3RIUS_ID
from clockblocker_bot.utils.rotate_words import rotate_words
from clockblocker_bot.utils.decorators import (
    beware_the_croud_policy,
    clean_up_policy,
    ignore_with_id,
    mark_unread,
)
from telethon import events

logger = logging.getLogger(__name__)


@config.telegram_client.on(events.NewMessage(pattern="^.h$"))
@mark_unread
@clean_up_policy
async def show_help(event: events.NewMessage.Event):
    help_text = Path(__file__).parent / "static_messages" / "help.txt"
    print('h')
    with open(help_text) as f:
        contents = f.read()
    return await event.respond(contents)


@config.telegram_client.on(
    events.NewMessage(pattern=r"\W*[пП]+\s*[рР]+\s*[иИ]+\s*[вВ]+\s*[Ее]+\s*[тТ]+\W*")
)
@ignore_with_id(CLOCKBLOCKER_ID)
@beware_the_croud_policy(config.telegram_client)
@mark_unread
@clean_up_policy
async def ci(event: events.NewMessage.Event):
    return await event.respond("Как дела?")


@config.telegram_client.on(
    events.NewMessage(
        pattern=re.compile(r".*(Блядь|БлsDь|лябдь|,zklm|блядь|Блядь|бляьд|Бляьд).*", flags=re.DOTALL | re.MULTILINE),
        outgoing=True,
    )
)
@mark_unread
async def blyad(event: events.NewMessage.Event):
    blyads = ["Блядь", "БлsDь", "лябдь", ",zklm", "блядь", "Блядь", "бляьд", "Бляьд"]
    start_time = datetime.now()
    current_time = start_time
    s = event.message.message
    
    while (current_time - start_time).seconds < 10:
        s = rotate_words(s, blyads)
        print('message: ',  event.message.message, s)
        await event.message.edit(s)
        await asyncio.sleep(1)
        current_time = datetime.now()


@config.telegram_client.on(events.NewMessage(pattern=r".*сломал(ось|ись|ась|ся).*"))
@mark_unread
@clean_up_policy
async def reboot_advice(event: events.NewMessage.Event):
    return await event.respond("Стоит попробовать выключить и включить")


@config.telegram_client.on(events.NewMessage(pattern=r"[\)\s]+"))
@ignore_with_id(S3RIUS_ID, CLOCKBLOCKER_ID)
@clean_up_policy
@mark_unread
async def smile_back(event: events.NewMessage.Event):
    return await event.respond(event.message.message)

@config.telegram_client.on(events.NewMessage(pattern=r".*(З|зумеры).*"))
@mark_unread
@clean_up_policy
async def zoomers(event: events.NewMessage.Event):
    return await event.respond("уууу тиктокеры")

@config.telegram_client.on(events.NewMessage(pattern=r".*(З|зумер).*"))
@mark_unread
@clean_up_policy
async def zoomer(event: events.NewMessage.Event):
    return await event.respond("уууу тиктокер")


@config.telegram_client.on(events.NewMessage(pattern=".*@all.*", forwards=False))
@mark_unread
@beware_the_croud_policy(config.telegram_client)
async def mention_all(event: events.NewMessage.Event):
    if event.is_group:
        chat = await event.get_chat()
        participants = []
        async for participant in config.telegram_client.iter_participants(chat):
            if participant.username:
                if participant.username.lower().endswith("bot"):
                    continue
                participants.append(f"@{participant.username}")
            else:
                participants.append(
                    f"[{participant.first_name}](tg://user?id={participant.id})"
                )
        await event.respond(" ".join(participants))
